# Examples

This section contains practical examples of using ArchiPy components.

## Adapters

- [PostgreSQL](adapters/postgres.md)
- [SQLite](adapters/sqlite.md)
- [StarRocks](adapters/starrocks.md)
- [Redis](adapters/redis.md)
- [Email](adapters/email.md)
- [Keycloak](adapters/keycloak.md)
- [MinIO](adapters/minio.md)
- [Kafka](adapters/kafka.md)
- [Temporal](adapters/temporal.md)
- [Payment Gateways](adapters/parsian_payment.md)

## Helpers

- [Decorators](helpers/decorators.md)
- [Interceptors](helpers/interceptors.md)
- [Utils](helpers/utils.md)

## Configuration

- [Configuration Management](config_management.md)

## Testing

- [BDD Testing](bdd_testing.md)

## Models

- [Protobuf DTOs](models/protobuf_dtos.md)

## Error Handling

- [Error Handling Examples](error_handling.md)
